@@ -71,7 +71,7 @@ export class Parser {
     // Labels in scope.
     this.labels = []
     // Thus-far undefined exports.
-    this.undefinedExports = {}
+    this.undefinedExports = Object.create(null)
 
     // If enabled, skip leading hashbang line.
     if (this.pos === 0 && options.allowHashBang && this.input.slice(0, 2) === "#!")
